<?php
/*
 * ----------------------------------------------------------------------------
 * Va-ChannelX.inc.php                                               03/14/2003
 * This script will retrieve all of the informaton related to the configured
 * channels.
 * ----------------------------------------------------------------------------
 * Copyright (C) 2002-2003 Steve Winn. All Rights Reserved.
 *
 * The source code contains a fair amount of comments, which may aid anyone
 * attempting to follow the program or to modify it.
 *
 * For licensing and copyright information, view LICENSE.TXT.
 * ----------------------------------------------------------------------------
 */

require_once('va-functions.inc.php');       // A VADV-PHP script.


/**
* Va-ChannelX.inc.php :: GetChannels()
*
* Retrieve all of the channel information and store it into a
* multidimensional array.
*
* Array format: $channels[1]['setting']
*               $channels[0] = Total number of nodes.
*
*/
function GetChannels() {
    $fileString = ReadChannels();
    if (!$fileString) trigger_error(VA_Error(3));

    $string   = 'tmp';
    $channels = array();                    // Create the array.

    for ($x = 0; $string <> ''; $x++) {
        $offset = 204 * $x;
        $string = GetInteger($fileString, $offset + 182);
        if ($string <> 0) {
            $channels[$x + 1]['init1']      = GetString($fileString, 1 + $offset, 40);
            $channels[$x + 1]['init2']      = GetString($fileString, 41 + $offset, 40);
            $channels[$x + 1]['init3']      = GetString($fileString, 81 + $offset, 40);
            $channels[$x + 1]['answer']     = GetString($fileString, 121 + $offset, 20);
            $channels[$x + 1]['dial']       = GetString($fileString, 141 + $offset, 20);
            $channels[$x + 1]['offhook']    = GetString($fileString, 161 + $offset, 20);
            $channels[$x + 1]['baudrate']   = GetLongInt($fileString, 181 + $offset);
            $channels[$x + 1]['lockedbaud'] = GetInteger($fileString, 185 + $offset);
            $channels[$x + 1]['rtscts']     = GetInteger($fileString, 187 + $offset);
            $channels[$x + 1]['serialport'] = GetInteger($fileString, 189 + $offset);
            $channels[$x + 1]['baseaddy']   = dechex(GetInteger($fileString, 193 + $offset));
            $channels[$x + 1]['irq']        = dechex(GetInteger($fileString, 195 + $offset));
            $channels[$x + 1]['minbaud']    = GetLongInt($fileString, 197 + $offset);
        }
    }

    $channels[0] = $x - 1;                  // Put the number of doors in position 0.

    return $channels;                       // Return the upload protocols.

}


/**
* Va-ChannelX.inc.php :: PutChannels()
*
* This function will change the channelx.cfg to match the configuration variable
* passed. It then returns the new file string. The configuration variable MUST
* be in the format of $variable[1]['setting'].
*
*/
function PutChannels($fileString, $configVariable) {
    if (!is_string($fileString))    trigger_error(VA_Error(1));
    if (!is_array($configVariable)) trigger_error(VA_Error(1));

    $length  = count($configVariable);      // Get the number of elements in the config variable.
    $pointer = 0;                           // Reset the pointer.

    for ($x = 0; $pointer < $length; $x++) {
        $offset = 73 * $x;
        if (isset($configVariable[$x + 1])) {
            $pointer++;
            if (isset($configVariable[$x + 1]['key']))     $fileString = PutString($fileString, $configVariable[$x + 1]['key'], 1 + $offset, 1);
            if (isset($configVariable[$x + 1]['desc']))    $fileString = PutString($fileString, $configVariable[$x + 1]['desc'], 2 + $offset, 23);
            if (isset($configVariable[$x + 1]['batch']))   $fileString = PutInteger($fileString, $configVariable[$x + 1]['batch'], 25 + $offset);
            if (isset($configVariable[$x + 1]['command'])) $fileString = PutString($fileString, $configVariable[$x + 1]['command'], 26 + $offset, 48);

            if (isset($configVariable[$x + 1]['init1']))      $fileString = PutString($fileString, $configVariable[$x + 1]['init1'], 1 + $offset, 40);
            if (isset($configVariable[$x + 1]['init2']))      $fileString = PutString($fileString, $configVariable[$x + 1]['init2'], 41 + $offset, 40);
            if (isset($configVariable[$x + 1]['init3']))      $fileString = PutString($fileString, $configVariable[$x + 1]['init3'], 81 + $offset, 40);
            if (isset($configVariable[$x + 1]['answer']))     $fileString = PutString($fileString, $configVariable[$x + 1]['answer'], 121 + $offset, 20);
            if (isset($configVariable[$x + 1]['dial']))       $fileString = PutString($fileString, $configVariable[$x + 1]['dial'], 141 + $offset, 20);
            if (isset($configVariable[$x + 1]['offhook']))    $fileString = PutString($fileString, $configVariable[$x + 1]['offhook'], 161 + $offset, 20);
            if (isset($configVariable[$x + 1]['baudrate']))   $fileString = PutLongInt($fileString, $configVariable[$x + 1]['baudrate'], 181 + $offset);
            if (isset($configVariable[$x + 1]['lockedbaud'])) $fileString = PutInteger($fileString, $configVariable[$x + 1]['lockedbaud'], 185 + $offset);
            if (isset($configVariable[$x + 1]['rtscts']))     $fileString = PutInteger($fileString, $configVariable[$x + 1]['rtscts'], 187 + $offset);
            if (isset($configVariable[$x + 1]['serialport'])) $fileString = PutInteger($fileString, $configVariable[$x + 1]['serialport'], 189 + $offset);
            if (isset($configVariable[$x + 1]['baseaddy']))   $fileString = hexdec(PutInteger($fileString, $configVariable[$x + 1]['baseaddy'], 193 + $offset));
            if (isset($configVariable[$x + 1]['irq']))        $fileString = hexdec(PutInteger($fileString, $configVariable[$x + 1]['irq'], 195 + $offset));
            if (isset($configVariable[$x + 1]['minbaud']))    $fileString = PutLongInt($fileString, $configVariable[$x + 1]['minbaud'], 197 + $offset);
        }
    }

    return $fileString;                     // Return the new file string.
}


/**
* Va-ChannelX.inc.php :: ReadChannels()
*
* This function will read the channelx.cfg file.
*
*/
function ReadChannels() {
    global $VA_SYSPATHS;                    // Include the global variable.

    // Set the filename.
    $file = $VA_SYSPATHS['main'] . '/channelx.cfg';
    if (!is_file($file)) return FALSE;

    $fileString = ReadCfgFile($file);       // Read the file.

    return $fileString;                     // Return the file string.
}


/**
* Va-ChannelX.inc.php :: WriteChannels()
*
* This function will write a new channelx.cfg file based on the file string
* passed to it. If the file string is not in the correct format, then your
* channelx.cfg file will become corrupt and the BBS could stop functioning!
*
*/
function WriteChannels($fileString) {
    if (!is_string($fileString)) trigger_error(VA_Error(1));

    global $VA_SYSPATHS;                    // Include the global variable.

    // Set the filename.
    $file = $VA_SYSPATHS['main'] . '/channelx.cfg';
    if (!is_file($file)) return FALSE;

    $status = WriteCfgFile($file, $fileString);

    return $status;                         // Return the result status.
}


// Retrieve the channels automatically.
$VA_CHANNELS = GetChannels();

?>
