<?php
/*
 * ----------------------------------------------------------------------------
 * Va-Doors.inc.php                                                  02/20/2003
 * This script will retrieve all of the informaton related to the configured
 * doors that are found in DOORS.CFG.
 * ----------------------------------------------------------------------------
 * Copyright (C) 2002-2003 Steve Winn. All Rights Reserved.
 *
 * The source code contains a fair amount of comments, which may aid anyone
 * attempting to follow the program or to modify it.
 *
 * For licensing and copyright information, view LICENSE.TXT.
 * ----------------------------------------------------------------------------
 */

require_once('va-functions.inc.php');       // A VADV-PHP script.


/**
* Va-Doors.inc.php :: GetDoors()
*
* Retrieve all of the doors information and store it into a multidimensional
* array.
*
* Array format: $door[1]['setting']
*               $door[0] = Total number of doors.
*
*/
function GetDoors() {
    $fileString = ReadDoors();
    if (!$fileString) trigger_error(VA_Error(3));

    $string = 'tmp';
    $doors  = array();                      // Create the array.

    for ($x = 0; $string <> ''; $x++) {
        $offset = 75 * $x;
        $string = GetString($fileString, $offset + 1, 32);
        if ($string <> '') {
            $doors[$x + 1]['desc']       = GetString($fileString, 1 + $offset, 32);
            $doors[$x + 1]['command']    = GetString($fileString, 33 + $offset, 32);
            $doors[$x + 1]['minsl']      = GetInteger($fileString, 65 + $offset);
            $doors[$x + 1]['accflag']    = GetString($fileString, 67 + $offset, 1);
            $doors[$x + 1]['singleuser'] = GetInteger($fileString, 68 + $offset);
            $doors[$x + 1]['credits']    = GetInteger($fileString, 70 + $offset);
        }
    }

    $doors[0] = $x - 1;                     // Put the number of doors in position 0.

    return $doors;                          // Return the doors.

}


/**
* Va-Doors.inc.php :: PutDoors()
*
* This function will change the doors.cfg to match the configuration variable
* passed. It then returns the new file string. The configuration variable MUST
* be in the format of $variable[1]['setting'].
*
*/
function PutDoors($fileString, $configVariable) {
    if (!is_string($fileString))    trigger_error(VA_Error(1));
    if (!is_array($configVariable)) trigger_error(VA_Error(1));

    $length  = count($configVariable);      // Get the number of elements in the config variable.
    $pointer = 0;                           // Reset the pointer.

    for ($x = 0; $pointer < $length; $x++) {
        $offset = 75 * $x;
        if (isset($configVariable[$x + 1])) {
            $pointer++;
            if (isset($configVariable[$x + 1]['desc']))       $fileString = PutString($fileString, $configVariable[$x + 1]['desc'], 1 + $offset, 32);
            if (isset($configVariable[$x + 1]['command']))    $fileString = PutString($fileString, $configVariable[$x + 1]['command'], 33 + $offset, 32);
            if (isset($configVariable[$x + 1]['minsl']))      $fileString = PutInteger($fileString, $configVariable[$x + 1]['minsl'], 65 + $offset);
            if (isset($configVariable[$x + 1]['accflag']))    $fileString = PutString($fileString, $configVariable[$x + 1]['accflag'], 67 + $offset, 1);
            if (isset($configVariable[$x + 1]['singleuser'])) $fileString = PutInteger($fileString, $configVariable[$x + 1]['singleuser'], 68 + $offset);
            if (isset($configVariable[$x + 1]['credits']))    $fileString = PutInteger($fileString, $configVariable[$x + 1]['credits'], 70 + $offset);
        }
    }

    return $fileString;                     // Return the new file string.
}


/**
* Va-Doors.inc.php :: ReadDoors()
*
* This function will read the doors.cfg file.
*
*/
function ReadDoors() {
    global $VA_SYSPATHS;                    // Include the global variable.

    // Set the filename.
    $file = $VA_SYSPATHS['main'] . '/doors.cfg';
    if (!is_file($file)) return FALSE;

    $fileString = ReadCfgFile($file);       // Read the file.

    return $fileString;                     // Return the file string.
}


/**
* Va-Doors.inc.php :: WriteDoors()
*
* This function will write a new doors.cfg file based on the file string
* passed to it. If the file string is not in the correct format, then your
* doors.cfg file will become corrupt and the BBS could stop functioning!
*
*/
function WriteDoors($fileString) {
    if (!is_string($fileString)) trigger_error(VA_Error(1));

    global $VA_SYSPATHS;                    // Include the global variable.

    // Set the filename.
    $file = $VA_SYSPATHS['main'] . '/doors.cfg';
    if (!is_file($file)) return FALSE;

    $status = WriteCfgFile($file, $fileString);

    return $status;                         // Return the result status.
}


// Retrieve the doors automatically.
$VA_DOORS = GetDoors();

?>
