<?php
/*
 * ----------------------------------------------------------------------------
 * Va-Syspaths.inc.php                                               02/24/2003
 * This script will read the syspaths.cfg file and place its information into
 * an array for global use.
 * ----------------------------------------------------------------------------
 * Copyright (C) 2002-2003 Steve Winn. All Rights Reserved.
 *
 * The source code contains a fair amount of comments, which may aid anyone
 * attempting to follow the program or to modify it.
 *
 * For licensing and copyright information, view LICENSE.TXT.
 * ----------------------------------------------------------------------------
 */

require_once('va-functions.inc.php');       // A VADV-PHP script.


/**
* Va-Syspaths.inc.php :: ConvertDir()
*
* This function will convert a local directory into a network address.
*
*/
function ConvertDir($hostname, $dir) {
    $drive = substr($dir, 0, 1);            // Get the drive letter.
    $line  = substr($dir, 2);               // Get the rest of the path.
    $path  = '//' . trim($hostname) . '/' . trim($drive) . trim($line);

    return $path;                           // Return the new path.
}


/**
* Va-Syspaths.inc.php :: ConvertUnc()
*
* This function will convert a UNC path into a local directory.
*
*/
function ConvertUnc($unc) {
    $pos   = strpos($unc, '/', 2);          // Get the position of the drive letter.
    $drive = substr($unc, $pos + 1, 1);     // Get the drive letter.
    $dir   = substr($unc, $pos + 3);        // Get the rest of the path.
    if ($dir == '') {
        $path  = $drive . ':';
    } else {
        $path  = $drive . ":\\" . $dir;
    }

    return $path;                           // Return the new path.
}


/**
* Va-Syspaths.inc.php :: GetConfig()
*
* This function will read the VADV-PHP configuration file (vadv-php_config.php)
* and place its variables into an array.
*
*/
function GetConfig() {
    // Set the default values.
    $config = array();
    $config['bbsdir']       = 'c:/va';
    $config['filehost']     = '';
    $config['hostname']     = '';
    $config['telnet']       = '';
    $config['useraccflags'] = '';
    $config['userage']      = 0;
    $config['usersl']       = 15;
    $config['webmaster']    = 'webmaster@';

    include('vadv-php_config.php');         // Include the configuration file.

    return $config;
}


/**
* Va-SysPaths.inc.php :: WriteConfig()
*
* This function will write a new vadv-php_config.php file based on the values in
* the configuration variable. The configuration variable should be set to the
* values of $CONFIG before you assign any new values to it to prevent errors
* being written to, or left out of the config file.
*
*/
function WriteConfig($configVariable) {
    $fp = fopen('vadv-php_config.php', 'r+', 1);
    if (!$fp) return FALSE;
    
    

    fclose($fp);
    
    return $status;                         // Return the status.
}


/**
* Va-Syspaths.inc.php :: GetSysPaths()
*
* This function will retrieve the vadv system paths from the syspaths.cfg file
* and return the paths in an array.
*
*/
function GetSysPaths() {
    global $CONFIG;                         // Include the global variable.

    $fileString = ReadSysPaths();           // Read the file.

    $syspaths = array();
    $syspaths['main'] = GetString($fileString, 1, 40);
    if ($CONFIG['hostname'] != '') $syspaths['main']    = ConvertDir($CONFIG['hostname'], $syspaths['main']);
    $syspaths['script'] = GetString($fileString, 41, 40);
    if ($CONFIG['hostname'] != '') $syspaths['script']  = ConvertDir($CONFIG['hostname'], $syspaths['script']);
    $syspaths['data'] = GetString($fileString, 81, 40);
    if ($CONFIG['hostname'] != '') $syspaths['data']    = ConvertDir($CONFIG['hostname'], $syspaths['data']);
    $syspaths['network'] = GetString($fileString, 121, 40);
    if ($CONFIG['hostname'] != '') $syspaths['network'] = ConvertDir($CONFIG['hostname'], $syspaths['network']);
    $syspaths['text'] = GetString($fileString, 161, 40);
    if ($CONFIG['hostname'] != '') $syspaths['text']    = ConvertDir($CONFIG['hostname'], $syspaths['text']);
    $syspaths['control'] = GetString($fileString, 201, 40);
    if ($CONFIG['hostname'] != '') $syspaths['control'] = ConvertDir($CONFIG['hostname'], $syspaths['control']);
    $syspaths['temp'] = GetString($fileString, 241, 40);
    if ($CONFIG['hostname'] != '') $syspaths['temp']    = ConvertDir($CONFIG['hostname'], $syspaths['temp']);
    $syspaths['db'] = GetString($fileString, 281, 40);
    if ($CONFIG['hostname'] != '') $syspaths['db']      = ConvertDir($CONFIG['hostname'], $syspaths['db']);
    $syspaths['sysop'] = GetString($fileString, 321, 40);
    if ($CONFIG['hostname'] != '') $syspaths['sysop']   = ConvertDir($CONFIG['hostname'], $syspaths['sysop']);
    $syspaths['fdx'] = GetString($fileString, 361, 40);
    if ($CONFIG['hostname'] != '') $syspaths['fdx']     = ConvertDir($CONFIG['hostname'], $syspaths['fdx']);
    
    return $syspaths;                       // Return the BBS system paths.
}


/**
* Va-SysPaths.inc.php :: PutSysPaths()
*
* This function will write updated information to the control.dat file, which
* is used to determine the current users online.
*
*/
function PutSysPaths($fileString, $configVariable) {
    if (!is_string($fileString))    trigger_error(VA_Error(1));
    if (!is_array($configVariable)) trigger_error(VA_Error(1));

    if (isset($configVariable['main']))    $fileString = PutString($fileString, $configVariable['main'], 1, 40);
    if (isset($configVariable['script']))  $fileString = PutString($fileString, $configVariable['script'], 41, 40);
    if (isset($configVariable['data']))    $fileString = PutString($fileString, $configVariable['data'], 81, 40);
    if (isset($configVariable['network'])) $fileString = PutString($fileString, $configVariable['network'], 121, 32);
    if (isset($configVariable['text']))    $fileString = PutString($fileString, $configVariable['text'], 161, 32);
    if (isset($configVariable['control'])) $fileString = PutString($fileString, $configVariable['control'], 201, 3);
    if (isset($configVariable['temp']))    $fileString = PutString($fileString, $configVariable['temp'], 241, 10);
    if (isset($configVariable['db']))      $fileString = PutString($fileString, $configVariable['db'], 281, 12);
    if (isset($configVariable['sysop']))   $fileString = PutString($fileString, $configVariable['sysop'], 321, 12);
    if (isset($configVariable['fdx']))     $fileString = PutString($fileString, $configVariable['fdx'], 361, 12);

    return $fileString;
}


/**
* Va-SysPaths.inc.php :: ReadSysPaths()
*
* This function will read the syspaths.cfg file.
*
*/
function ReadSysPaths() {
    global $CONFIG;                         // Include the global variable.

    // Check to see if a hostname was configured for a network path.
    if (trim($CONFIG['hostname']) == '') {
        $file = trim($CONFIG['bbsdir']) . '/syspaths.cfg';
    } else {
        $file = ConvertDir($CONFIG['hostname'], $CONFIG['bbsdir']) . '/SYSPATHS.CFG';
    }

    $fileString = ReadCfgFile($file);       // Read the file.

    return $fileString;                     // Return the file string.
}


/**
* Va-SysPaths.inc.php :: WriteSysPaths()
*
* This function will write a new syspaths.cfg file based on the file string
* passed to it. If the file string is not in the correct format, then your
* syspaths.cfg file will become corrupt and the BBS could stop functioning!
*
*/
function WriteSysPaths($fileString) {
    if (!is_string($fileString)) trigger_error(VA_Error(1));

    global $VA_SYSPATHS;                    // Include the global variable.

    // Set the filename.
    $file = $VA_SYSPATHS['main'] . '/syspaths.cfg';
    if (!is_file($file)) return FALSE;

    $status = WriteCfgFile($file, $fileString);

    return $status;                         // Return the result status.
}


// Read the configuration file.
$CONFIG = GetConfig();                      // Get the configuration using vadv-php_config.php.

// Load all of the syspaths.cfg variables automatically.
$VA_SYSPATHS = GetSysPaths();

?>
