<?php
/*
 * ----------------------------------------------------------------------------
 * Va-Vote.inc.php                                                   02/20/2003
 * This script will retrieve all of the informaton related to the configured
 * voting informatoin that are found in VOTE.CFG.
 * ----------------------------------------------------------------------------
 * Copyright (C) 2002-2003 Steve Winn. All Rights Reserved.
 *
 * The source code contains a fair amount of comments, which may aid anyone
 * attempting to follow the program or to modify it.
 *
 * For licensing and copyright information, view LICENSE.TXT.
 * ----------------------------------------------------------------------------
 */

require_once('va-functions.inc.php');       // A VADV-PHP script.


/**
* Va-Vote.inc.php :: GetVote()
*
* Retrieve all of the voting information and store it into a multidimensional
* array.
*
* Array format: $vote[1]['setting']
*               $vote[0] = Total number of questions.
*
*/
function GetVote() {
    $fileString = ReadVote();
    if (!$fileString) trigger_error(VA_Error(3));

    $string = 'tmp';
    $vote   = array();                      // Create the array.

    for ($x = 0; $string <> ''; $x++) {
        $offset = 547 * $x;
        $string = GetString($fileString, $offset + 1, 32);
        if ($string <> '') {
            $vote[$x + 1]['question'] = GetString($fileString, 1 + $offset, 64);
            $vote[$x + 1]['respno']   = GetInteger($fileString, 65 + $offset);
            $vote[$x + 1]['resp1']    = GetString($fileString, 67 + $offset, 60);
            $vote[$x + 1]['resp2']    = GetString($fileString, 127 + $offset, 60);
            $vote[$x + 1]['resp3']    = GetString($fileString, 187 + $offset, 60);
            $vote[$x + 1]['resp4']    = GetString($fileString, 247 + $offset, 60);
            $vote[$x + 1]['resp5']    = GetString($fileString, 307 + $offset, 60);
            $vote[$x + 1]['resp6']    = GetString($fileString, 367 + $offset, 60);
            $vote[$x + 1]['resp7']    = GetString($fileString, 427 + $offset, 60);
            $vote[$x + 1]['resp8']    = GetString($fileString, 487 + $offset, 60);
        }
    }

    $vote[0] = $x - 1;                      // Put the number of voting questions in position 0.

    return $vote;                           // Return the voting information.

}


/**
* Va-Vote.inc.php :: PutVote()
*
* This function will change the vote.cfg to match the configuration variable
* passed. It then returns the new file string. The configuration variable MUST
* be in the format of $variable[1]['setting'].
*
*/
function PutUpload($fileString, $configVariable) {
    if (!is_string($fileString))    trigger_error(VA_Error(1));
    if (!is_array($configVariable)) trigger_error(VA_Error(1));

    $length  = count($configVariable);      // Get the number of elements in the config variable.
    $pointer = 0;                           // Reset the pointer.

    for ($x = 0; $pointer < $length; $x++) {
        $offset = 547 * $x;
        if (isset($configVariable[$x + 1])) {
            $pointer++;
            if (isset($configVariable[$x + 1]['question'])) $fileString = PutString($fileString, $configVariable[$x + 1]['question'], 1 + $offset, 64);
            if (isset($configVariable[$x + 1]['respno']))   $fileString = PutInteger($fileString, $configVariable[$x + 1]['respno'], 65 + $offset);
            if (isset($configVariable[$x + 1]['resp1']))    $fileString = PutString($fileString, $configVariable[$x + 1]['resp1'], 67 + $offset, 60);
            if (isset($configVariable[$x + 1]['resp2']))    $fileString = PutString($fileString, $configVariable[$x + 1]['resp2'], 127 + $offset, 60);
            if (isset($configVariable[$x + 1]['resp3']))    $fileString = PutString($fileString, $configVariable[$x + 1]['resp3'], 187 + $offset, 60);
            if (isset($configVariable[$x + 1]['resp4']))    $fileString = PutString($fileString, $configVariable[$x + 1]['resp4'], 247 + $offset, 60);
            if (isset($configVariable[$x + 1]['resp5']))    $fileString = PutString($fileString, $configVariable[$x + 1]['resp5'], 307 + $offset, 60);
            if (isset($configVariable[$x + 1]['resp6']))    $fileString = PutString($fileString, $configVariable[$x + 1]['resp6'], 367 + $offset, 60);
            if (isset($configVariable[$x + 1]['resp7']))    $fileString = PutString($fileString, $configVariable[$x + 1]['resp7'], 427 + $offset, 60);
            if (isset($configVariable[$x + 1]['resp8']))    $fileString = PutString($fileString, $configVariable[$x + 1]['resp8'], 487 + $offset, 60);
        }
    }

    return $fileString;                     // Return the new file string.
}


/**
* Va-Vote.inc.php :: ReadVote()
*
* This function will read the vote.cfg file.
*
*/
function ReadVote() {
    global $VA_SYSPATHS;                    // Include the global variable.

    // Set the filename.
    $file = $VA_SYSPATHS['main'] . '/vote.cfg';
    if (!is_file($file)) return FALSE;

    $fileString = ReadCfgFile($file);       // Read the file.

    return $fileString;                     // Return the file string.
}


/**
* Va-Vote.inc.php :: WriteVote()
*
* This function will write a new vote.cfg file based on the file string
* passed to it. If the file string is not in the correct format, then your
* vote.cfg file will become corrupt and the BBS could stop functioning!
*
*/
function WriteVote($fileString) {
    if (!is_string($fileString)) trigger_error(VA_Error(1));

    global $VA_SYSPATHS;                    // Include the global variable.

    // Set the filename.
    $file = $VA_SYSPATHS['main'] . '/vote.cfg';
    if (!is_file($file)) return FALSE;

    $status = WriteCfgFile($file, $fileString);

    return $status;                         // Return the result status.
}


// Retrieve the voting information automatically.
$VA_VOTE = GetVote();

?>
